@@ -2,20 +2,32 @@ from datetime import date, datetime
 from decimal import Decimal
 from unittest import skipUnless
 
+from django import VERSION
 from django.contrib.postgres.functions import TransactionNow
 from django.db import connection
 from django.test import TransactionTestCase, override_settings
-from psycopg2.extras import NumericRange, DateRange, DateTimeTZRange
+
+# If we are using Django 4.2 or higher, we need to use:
+if VERSION >= (4, 2):
+    from django.db.backends.postgresql.psycopg_any import (
+        DateRange,
+        DateTimeTZRange,
+        NumericRange,
+    )
+else:
+    from psycopg2.extras import DateRange, DateTimeTZRange, NumericRange
+
 from pytz import timezone
 
 from ..utils import UncachableQuery
 from .api import invalidate
 from .models import PostgresModel, Test
 from .test_utils import TestUtilsMixin
-
+from .tests_decorators import all_final_sql_checks, no_final_sql_check, with_final_sql_check
 
 # FIXME: Add tests for aggregations.
 
+
 def is_pg_field_available(name):
     fields = []
     try:
@@ -91,14 +103,18 @@ class PostgresReadTestCase(TestUtilsMixin, TransactionTestCase):
         self.obj1.save()
         self.obj2.save()
 
+    @all_final_sql_checks
     def test_unaccent(self):
-        Test.objects.create(name='Clémentine')
-        Test.objects.create(name='Clementine')
+        obj1 = Test.objects.create(name='Clémentine')
+        obj2 = Test.objects.create(name='Clementine')
         qs = (Test.objects.filter(name__unaccent='Clémentine')
               .values_list('name', flat=True))
         self.assert_tables(qs, Test)
         self.assert_query_cached(qs, ['Clementine', 'Clémentine'])
+        obj1.delete()
+        obj2.delete()
 
+    @all_final_sql_checks
     def test_int_array(self):
         with self.assertNumQueries(1):
             data1 = [o.int_array for o in PostgresModel.objects.all()]
@@ -145,6 +161,7 @@ class PostgresReadTestCase(TestUtilsMixin, TransactionTestCase):
         self.assert_tables(qs, PostgresModel)
         self.assert_query_cached(qs, [[1, 2, 3]])
 
+    @all_final_sql_checks
     def test_hstore(self):
         with self.assertNumQueries(1):
             data1 = [o.hstore for o in PostgresModel.objects.all()]
@@ -198,6 +215,7 @@ class PostgresReadTestCase(TestUtilsMixin, TransactionTestCase):
         self.assert_tables(qs, PostgresModel)
         self.assert_query_cached(qs, [{'a': '1', 'b': '2'}])
 
+    @all_final_sql_checks
     @skipUnless(is_pg_field_available("JSONField"),
                 "JSONField was removed in Dj 4.0")
     def test_json(self):
@@ -309,6 +327,7 @@ class PostgresReadTestCase(TestUtilsMixin, TransactionTestCase):
         self.assertListEqual(list(qs.all()),
                              [self.obj1.json, self.obj2.json])
 
+    @all_final_sql_checks
     def test_int_range(self):
         with self.assertNumQueries(1):
             data1 = [o.int_range for o in PostgresModel.objects.all()]
@@ -378,13 +397,16 @@ class PostgresReadTestCase(TestUtilsMixin, TransactionTestCase):
         self.assert_tables(qs, PostgresModel)
         self.assert_query_cached(qs, [NumericRange(1900, 2000)])
 
-        PostgresModel.objects.create(int_range=[1900, 1900])
+        obj = PostgresModel.objects.create(int_range=[1900, 1900])
 
         qs = (PostgresModel.objects.filter(int_range__isempty=True)
               .values_list('int_range', flat=True))
         self.assert_tables(qs, PostgresModel)
         self.assert_query_cached(qs, [NumericRange(empty=True)])
 
+        obj.delete()
+
+    @all_final_sql_checks
     @skipUnless(is_pg_field_available("FloatRangeField"),
                 "FloatRangeField was removed in Dj 3.1")
     def test_float_range(self):
@@ -398,6 +420,7 @@ class PostgresReadTestCase(TestUtilsMixin, TransactionTestCase):
             NumericRange(Decimal('-1000.0'), Decimal('9.87654321')),
             NumericRange(Decimal('0.0'))])
 
+    @all_final_sql_checks
     @skipUnless(is_pg_field_available("DecimalRangeField"),
                 "DecimalRangeField was added in Dj 2.2")
     def test_decimal_range(self):
@@ -407,6 +430,7 @@ class PostgresReadTestCase(TestUtilsMixin, TransactionTestCase):
             NumericRange(Decimal('-1000.0'), Decimal('9.87654321')),
             NumericRange(Decimal('0.0'))])
 
+    @all_final_sql_checks
     def test_date_range(self):
         qs = PostgresModel.objects.values_list('date_range', flat=True)
         self.assert_tables(qs, PostgresModel)
@@ -414,6 +438,7 @@ class PostgresReadTestCase(TestUtilsMixin, TransactionTestCase):
             DateRange(date(1678, 3, 4), date(1741, 7, 28)),
             DateRange(date(1989, 1, 30))])
 
+    @all_final_sql_checks
     def test_datetime_range(self):
         qs = PostgresModel.objects.values_list('datetime_range', flat=True)
         self.assert_tables(qs, PostgresModel)
@@ -422,6 +447,7 @@ class PostgresReadTestCase(TestUtilsMixin, TransactionTestCase):
                                      tzinfo=timezone('Europe/Paris'))),
             DateTimeTZRange(bounds='()')])
 
+    @all_final_sql_checks
     def test_transaction_now(self):
         """
         Checks that queries with a TransactionNow() parameter are not cached.
@@ -431,3 +457,5 @@ class PostgresReadTestCase(TestUtilsMixin, TransactionTestCase):
         with self.assertRaises(UncachableQuery):
             self.assert_tables(qs, Test)
         self.assert_query_cached(qs, [obj], after=1)
+
+        obj.delete()
