@@ -249,6 +249,13 @@ class ReadTestCase(TestUtilsMixin, FilteredTransactionTestCase):
         self.assert_query_cached(qs, [t])
 
     def test_iterator(self):
+        with self.settings(CACHALOT_CACHE_ITERATORS=False):
+            with self.assertNumQueries(2):
+                data1 = list(Test.objects.iterator())
+                data2 = list(Test.objects.iterator())
+            self.assertListEqual(data2, data1)
+            self.assertListEqual(data2, [self.t1, self.t2])
+
         with self.assertNumQueries(1):
             data1 = list(Test.objects.iterator())
         with self.assertNumQueries(0):
