@@ -6,8 +6,8 @@ from typing import TYPE_CHECKING
 from uuid import UUID
 
 from django.contrib.postgres.functions import TransactionNow
-from django.db import connections
 from django.db.models import Exists, QuerySet, Subquery
+from django.db.models.enums import Choices
 from django.db.models.expressions import RawSQL
 from django.db.models.functions import Now
 from django.db.models.sql import Query, AggregateQuery
@@ -35,23 +35,42 @@ CACHABLE_PARAM_TYPES = {
 }
 UNCACHABLE_FUNCS = {Now, TransactionNow}
 
-try:
-    # TODO Drop after Dj30 drop
-    from django.contrib.postgres.fields.jsonb import JsonAdapter
-    CACHABLE_PARAM_TYPES.update((JsonAdapter,))
-except ImportError:
-    pass
 
 try:
-    from psycopg2 import Binary
-    from psycopg2.extras import (
-        NumericRange, DateRange, DateTimeRange, DateTimeTZRange, Inet, Json)
-except ImportError:
-    pass
-else:
+    from psycopg.dbapi20 import Binary
+
+    from django.db.backends.postgresql.psycopg_any import (
+        NumericRange, DateRange, DateTimeRange, DateTimeTZRange, Inet,
+    )
+    
+    from psycopg.types.numeric import (
+        Int2, Int4, Int8, Float4, Float8,
+    )
+
+    from ipaddress import (
+        IPv4Address,
+        IPv6Address,
+    )
+
+    from psycopg.types.json import (
+        Json, Jsonb,
+    )
+
     CACHABLE_PARAM_TYPES.update((
-        Binary, NumericRange, DateRange, DateTimeRange, DateTimeTZRange, Inet,
-        Json,))
+        NumericRange, DateRange, DateTimeRange, DateTimeTZRange, Inet, Json, Jsonb,
+        Int2, Int4, Int8, Float4, Float8, IPv4Address, IPv6Address,
+        Binary,
+    ))
+except ImportError:
+    try:
+        from psycopg2 import Binary
+        from psycopg2.extras import (
+            NumericRange, DateRange, DateTimeRange, DateTimeTZRange, Inet, Json)
+        CACHABLE_PARAM_TYPES.update((
+            Binary, NumericRange, DateRange, DateTimeRange, DateTimeTZRange, Inet,
+            Json,))
+    except ImportError:
+        pass
 
 
 def check_parameter_types(params):
@@ -62,6 +81,11 @@ def check_parameter_types(params):
                 check_parameter_types(p)
             elif cl is dict:
                 check_parameter_types(p.items())
+            elif issubclass(cl, Choices):
+                # Handle the case where a parameter from a Choices field is passed.
+                # Django Choices use enum.unique() so the values are guaranteed to be unique.
+                # Dereference the true "value" and verify that it is cachable.
+                check_parameter_types([p.value])
             else:
                 raise UncachableQuery
 
@@ -83,6 +107,10 @@ def get_query_cache_key(compiler):
     check_parameter_types(params)
     cache_key = '%s:%s:%s' % (compiler.using, sql,
                               [str(p) for p in params])
+    # Set attribute on compiler for later access
+    # to the generated SQL. This prevents another as_sql() call!
+    compiler.__cachalot_generated_sql = sql.lower()
+
     return sha1(cache_key.encode('utf-8')).hexdigest()
 
 
@@ -101,9 +129,23 @@ def get_table_cache_key(db_alias, table):
     return sha1(cache_key.encode('utf-8')).hexdigest()
 
 
-def _get_tables_from_sql(connection, lowercased_sql):
-    return {t for t in connection.introspection.django_table_names()
-            + cachalot_settings.CACHALOT_ADDITIONAL_TABLES if t in lowercased_sql}
+def _get_tables_from_sql(connection, lowercased_sql, enable_quote: bool = False):
+    """Returns names of involved tables after analyzing the final SQL query."""
+    return {table for table in (connection.introspection.django_table_names()
+            + cachalot_settings.CACHALOT_ADDITIONAL_TABLES)
+            if _quote_table_name(table, connection, enable_quote) in lowercased_sql}
+
+
+def _quote_table_name(table_name, connection, enable_quote: bool):
+    """
+    Returns quoted table name.
+
+    Put database-specific quotation marks around the table name
+    to preven that tables with substrings of the table are considered.
+    E.g. cachalot_testparent must not return cachalot_test.
+    """
+    return f'{connection.ops.quote_name(table_name)}' \
+        if enable_quote else table_name
 
 
 def _find_rhs_lhs_subquery(side):
@@ -113,13 +155,7 @@ def _find_rhs_lhs_subquery(side):
     elif h_class is QuerySet:
         return side.query
     elif h_class in (Subquery, Exists):  # Subquery allows QuerySet & Query
-        try:
-            return side.query.query if side.query.__class__ is QuerySet else side.query
-        except AttributeError:  # TODO Remove try/except closure after drop Django 2.2
-            try:
-                return side.queryset.query
-            except AttributeError:
-                return None
+        return side.query.query if side.query.__class__ is QuerySet else side.query
     elif h_class in UNCACHABLE_FUNCS:
         raise UncachableQuery
 
@@ -170,7 +206,7 @@ def filter_cachable(tables):
     return tables
 
 
-def _flatten(expression: "BaseExpression"):
+def _flatten(expression: 'BaseExpression'):
     """
     Recursively yield this expression and all subexpressions, in
     depth-first order.
@@ -187,7 +223,9 @@ def _flatten(expression: "BaseExpression"):
                 yield expr
 
 
-def _get_tables(db_alias, query):
+def _get_tables(db_alias, query, compiler=False):
+    from django.db import connections
+
     if query.select_for_update or (
             not cachalot_settings.CACHALOT_CACHE_RANDOM
             and '?' in query.order_by):
@@ -196,9 +234,11 @@ def _get_tables(db_alias, query):
     try:
         if query.extra_select:
             raise IsRawQuery
+
         # Gets all tables already found by the ORM.
         tables = set(query.table_map)
-        tables.add(query.get_meta().db_table)
+        if query.get_meta():
+            tables.add(query.get_meta().db_table)
 
         # Gets tables in subquery annotations.
         for annotation in query.annotations.values():
@@ -206,8 +246,10 @@ def _get_tables(db_alias, query):
                 raise UncachableQuery
             for expression in _flatten(annotation):
                 if isinstance(expression, Subquery):
-                    if hasattr(expression, "queryset"):
+                    # Django 2.2 only: no query, only queryset
+                    if not hasattr(expression, 'query'):
                         tables.update(_get_tables(db_alias, expression.queryset.query))
+                    # Django 3+
                     else:
                         tables.update(_get_tables(db_alias, expression.query))
                 elif isinstance(expression, RawSQL):
@@ -230,6 +272,18 @@ def _get_tables(db_alias, query):
     except IsRawQuery:
         sql = query.get_compiler(db_alias).as_sql()[0].lower()
         tables = _get_tables_from_sql(connections[db_alias], sql)
+    else:
+        # Additional check of the final SQL.
+        # Potentially overlooked tables are added here. Tables may be overlooked by the regular checks
+        # as not all expressions are handled yet. This final check acts as safety net.
+        if cachalot_settings.CACHALOT_FINAL_SQL_CHECK:
+            if compiler:
+                # Access generated SQL stored when caching the query!
+                sql = compiler.__cachalot_generated_sql
+            else:
+                sql = query.get_compiler(db_alias).as_sql()[0].lower()
+            final_check_tables = _get_tables_from_sql(connections[db_alias], sql, enable_quote=True)
+            tables.update(final_check_tables)
 
     if not are_all_cachable(tables):
         raise UncachableQuery
@@ -240,7 +294,7 @@ def _get_table_cache_keys(compiler):
     db_alias = compiler.using
     get_table_cache_key = cachalot_settings.CACHALOT_TABLE_KEYGEN
     return [get_table_cache_key(db_alias, t)
-            for t in _get_tables(db_alias, compiler.query)]
+            for t in _get_tables(db_alias, compiler.query, compiler)]
 
 
 def _invalidate_tables(cache, db_alias, tables):
